models

package
v0.0.0-...-cb95553 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Port

type Port struct {
	ID            string
	Name          string
	Description   string
	Shutdown      bool
	SecurityLevel int
	IPAddres      string
	Netmask       string
}

Port Contains the information to define an interface of a switch.

type Route

type Route struct {
	Name     string
	NextHop  string
	IPAddres string
	Netmask  string
}

Route Contains the information to define a route rule of a switch.

Jump to